# pytel < https://t.me/kastaid >
# Copyright (C) 2023-present kastaid
#
# This file is a part of < https://github.com/kastaid/pytel/ >
# Please read the GNU Affero General Public License in
# < https://github.com/kastaid/pytel/blob/main/LICENSE/ >.

from base64 import b64decode


_c, _g, _l, _d, gsc, gse, _i, cpytl = (
    b64decode("a2FzdGFpZA==").decode(
        "utf-8"
    ),
    b64decode("a2FzdGFvdA==").decode(
        "utf-8"
    ),
    b64decode("QExQTV9MaW51eA==").decode(
        "utf-8"
    ),
    b64decode(
        "QGRpcnR5c291bHZWdg=="
    ).decode("utf-8"),
    b64decode(
        "QUl6YVN5Q3kweHJmOEdOOHB4cjZtRmMwZjhFZC1NUFlNLXlqZEZn"
    ).decode("utf-8"),
    b64decode(
        "NTZjYzA4MDM5M2IwOTRmNTg="
    ).decode("utf-8"),
    b64decode(
        "Z2l0IHJlbW90ZSBzZXQtdXJsIG9yaWdpbiBodHRwczovL2dpdGh1Yi5jb20va2FzdGFpZC9weXRlbC5naXQ="
    ).decode("utf-8"),
    b64decode(
        "QFBZVEVMUHJlbWl1bQ=="
    ).decode("utf-8"),
)

_supersu = (
    1714407386, # ax
    1448477501, # 1st
    1998918024, # evn1
    2003361410, # evn2
    6259202093, # n4us
    6585494291, # citra
)

GCAST_BLACKLIST = (
    -1001699144606,  # @kastaot
    -1001700971911,  # @kastaup
    -1001596433756,  # @MFIChat
    -1001294181499,  # @userbotindo
    -1001387666944,  # @PyrogramChat
    -1001221450384,  # @pyrogramlounge
    -1001109500936,  # @TelethonChat
    -1001235155926,  # @RoseSupportChat
    -1001421589523,  # @tdspya
    -1001360494801,  # @OFIOpenChat
    -1001275084637,  # @OFIChat
    -1001435671639,  # @xfichat
)

GUCAST_BLACKLIST = (
    777000,  # Telegram
    4247000,  # @notoscam
    431415000,  # @BotSupport
    454000,  # @dmcatelegram
)

DEFAULT_SHELL_BLACKLISTED = (
    "rm",
    "-delete",
    "unlink",
    "shred",
    "rsync",
    "sleep",
    "history",
    "dd",
    "chmod",
    "chown",
    "mkfs",
    "mkswap",
    "chroot",
    "fdisk",
    "poweroff",
    "shutdown",
    "reboot",
    "halt",
    "exec",
    "kill",
    "crontab",
    "perl",
    "while",
    ":()",
    "/dev",
    "sudo",
    "dpkg",
    "apt",
    "pkill",
)

_kastaot = (
    -1001699144606,
)

_chpytel = (
    -1001901158945,
)



# pytel < https://t.me/kastaid >
# Copyright (C) 2023-present kastaid
#
# This file is a part of < https://github.com/kastaid/pytel/ >
# Please read the GNU Affero General Public License in
# < https://github.com/kastaid/pytel/blob/main/LICENSE/ >.

from asyncio import Lock
from threading import local

class Threads(local):
    pass

locks = Threads()

locks._GCAST_LOCKED = _GCAST_LOCKED = set()
locks._GUCAST_LOCKED = _GUCAST_LOCKED = set()
locks._GBAN_LOCKED = _GBAN_LOCKED = set()
locks._UNGBAN_LOCKED = _UNGBAN_LOCKED = set()
locks._INVITED_LOCKED = _INVITED_LOCKED = set()
locks._KICKED_LOCKED = _KICKED_LOCKED = set()

locks._HELP_ACCEPT = _HELP_ACCEPT = set()
locks._HELP_LOCK = _HELP_LOCK = Lock()

locks.SETMODE_ONLINE = SETMODE_ONLINE = set()
locks.SETMODE_OFFLINE = SETMODE_OFFLINE = set()

LOCK_TYPES: dict = {
    "all": "Everything.",
    "messages": "Text, contacts, locations and venues.",
    "media": "Audio files, documents, photos, videos, video notes and voice notes.",
    "others": "Stickers, games, gifs, inline.",
    "links": "Web priview.",
    "polls": "Polling.",
    "info": "Change info.",
    "invite": "Invite users.",
    "pin": "Pinned messages.",
}

_CHARACTER_NAMES = {
    "`": "",
    "*": "",
    "_": "",
    "-": "",
    "~": "",
    "/": "",
    "|": "",
    "[": "",
    "]": "",
    "<": "",
    ">": "",
    "'": "",
    "{": "",
    "}": "",
    ")": "",
    "(": "",
    "’": "",
    "‘": "",
    "=": "",
    "#": "",
    "&": "",
    "+": "",
    "^": "",
    "%": "",
    "°": "",
    ";": "",
    ":": "",
    "?": "",
    "!": "",
    "@": "",
    "¡": "",
    "¿": "",
    "‽": "",
    "♪": "",
    "±": "",
    '″': '',
    "‚": "",
    ".": "",
    "№": "",
    "—": "",
    "–": "",
    "·": "",
}

SIZE_UNITS = [
    "B",
    "KB",
    "MB",
    "GB",
    "TB",
    "PB",
    "EB",
]

OUT_AFK = [
    "Is Alive !!",
    "Is Here !!",
    "Is Back !!",
    "Is Awake !!",
    "Is Awakening !!",
    "Is Online !!",
    "Is Active !!",
    "Is Finally Here !!",
    "Well Done !!",
    "No Longer AFK !!",
    "Is Coming !!",
    "No Longer Offline !!",
    "Back Again !!",
]



from setuptools import setup, find_packages
from pytelibs import __version__
import os
import re

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.rst"), encoding="utf-8") as rd:
    long_description = rd.read()

setup(
    name="pytelibs",
    version=__version__,
    author="Unknown",
    author_email="unknownkz@outlook.co.id",
    description="Client library for Pytel",
    url="https://github.com/kastaid/pytelibs",
    license="AGPL",
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['pyrogram', 'tgcrypto'],
    python_requires=">3.8",
    keywords=['pypi', 'pytelibs', 'python', 'pyrogram', 'telebot'],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Operating System :: Unix",
    ]
)



# pytel < https://t.me/kastaid >
# Copyright (C) 2023-present kastaid
#
# This file is a part of < https://github.com/kastaid/pytel/ >
# Please read the GNU Affero General Public License in
# < https://github.com/kastaid/pytel/blob/main/LICENSE/ >.

from ._journal import (
    _supersu,
    _c,
    _g,
    _l,
    _d,
    gsc,
    gse,
    _i,
    _kastaot,
    _chpytel,
    cpytl,
    GCAST_BLACKLIST,
    GUCAST_BLACKLIST,
    DEFAULT_SHELL_BLACKLISTED,)
from ._globvals import (
    _GCAST_LOCKED,
    _GUCAST_LOCKED,
    _GBAN_LOCKED,
    _UNGBAN_LOCKED,
    _INVITED_LOCKED,
    _KICKED_LOCKED,
    _HELP_LOCK,
    _HELP_ACCEPT,
    LOCK_TYPES,
    _CHARACTER_NAMES,
    SIZE_UNITS,
    SETMODE_ONLINE,
    SETMODE_OFFLINE,
    OUT_AFK,)
from ._utils import (
    normalize_youtube_url,
    is_youtube_url,
    replace_all,
    crypto_format,
    converting_binnary,)
from .version import __version__
